==> singular_flutter_sdk-1.0.8.tar.gz: lib/attributes.dart <==
class Attributes{
	static String get sngAttrFromDate => "sng_attr_from_date";
	static String get sngAttrToDate => "sng_attr_to_date";
	static String get sngAttrAchievementId => "sng_attr_achievement_id";
	static String get sngAttrContent => "sng_attr_content";
	static String get sngAttrContentId => "sng_attr_content_id";
	static String get sngAttrContentList => "sng_attr_content_list";
	static String get sngAttrContentType => "sng_attr_content_type";
	static String get sngAttrCouponCode => "sng_attr_coupon_code";
	static String get sngAttrDeepLink => "sng_attr_deep_link";
	static String get sngAttrEventEnd => "sng_attr_event_end";
	static String get sngAttrEventStart => "sng_attr_event_start";
	static String get sngAttrHotelScore => "sng_attr_hotel_score";
	static String get sngAttrItemDescription => "sng_attr_item_description";
	static String get sngAttrItemPrice => "sng_attr_item_price";
	static String get sngAttrLatitude => "sng_attr_latitude";
	static String get sngAttrLevel => "sng_attr_level";
	static String get sngAttrLocation => "sng_attr_location";
	static String get sngAttrLocationAddressCountry => "sng_attr_location_address_country";
	static String get sngAttrLocationAddressRegionOrProvince => "sng_attr_location_address_region_or_province";
	static String get sngAttrLocationAddressStreet => "sng_attr_location_address_street";
	static String get sngAttrLongitude => "sng_attr_longitude";
	static String get sngAttrMax => "sng_attr_max";
	static String get sngAttrNewVersion => "sng_attr_new_version";
	static String get sngAttrOrigin => "sng_attr_origin";
	static String get sngAttrPaymentInfoAvailable => "sng_attr_payment_info_available";
	static String get sngAttrQuantity => "sng_attr_quantity";
	static String get sngAttrRating => "sng_attr_rating";
	static String get sngAttrRegistrationMethod => "sng_attr_registration_method";
	static String get sngAttrReviewText => "sng_attr_review_text";
	static String get sngAttrScore => "sng_attr_score";
	static String get sngAttrSearchString => "sng_attr_search_string";
	static String get sngAttrSubscriptionId => "sng_attr_subscription_id";
	static String get sngAttrSuccess => "sng_attr_success";
	static String get sngAttrTransactionId => "sng_attr_transaction_id";
	static String get sngAttrTutorialId => "sng_attr_tutorial_id";
	static String get sngAttrValid => "sng_attr_valid";
}

==> singular_flutter_sdk-1.2.1.tar.gz: lib/attributes.dart <==
class Attributes{
	static String get sngAttrFromDate => "sng_attr_from_date";
	static String get sngAttrToDate => "sng_attr_to_date";
	static String get sngAttrAchievementId => "sng_attr_achievement_id";
	static String get sngAttrContent => "sng_attr_content";
	static String get sngAttrContentId => "sng_attr_content_id";
	static String get sngAttrContentList => "sng_attr_content_list";
	static String get sngAttrContentType => "sng_attr_content_type";
	static String get sngAttrCouponCode => "sng_attr_coupon_code";
	static String get sngAttrDeepLink => "sng_attr_deep_link";
	static String get sngAttrEventEnd => "sng_attr_event_end";
	static String get sngAttrEventStart => "sng_attr_event_start";
	static String get sngAttrHotelScore => "sng_attr_hotel_score";
	static String get sngAttrItemDescription => "sng_attr_item_description";
	static String get sngAttrItemPrice => "sng_attr_item_price";
	static String get sngAttrLevel => "sng_attr_level";
	static String get sngAttrCountry => "sng_attr_country";
	static String get sngAttrRegion => "sng_attr_region";
	static String get sngAttrMax => "sng_attr_max";
	static String get sngAttrNewVersion => "sng_attr_new_version";
	static String get sngAttrOrigin => "sng_attr_origin";
	static String get sngAttrPaymentInfoAvailable => "sng_attr_payment_info_available";
	static String get sngAttrQuantity => "sng_attr_quantity";
	static String get sngAttrRating => "sng_attr_rating";
	static String get sngAttrRegistrationMethod => "sng_attr_registration_method";
	static String get sngAttrReviewText => "sng_attr_review_text";
	static String get sngAttrScore => "sng_attr_score";
	static String get sngAttrSearchString => "sng_attr_search_string";
	static String get sngAttrSubscriptionId => "sng_attr_subscription_id";
	static String get sngAttrSuccess => "sng_attr_success";
	static String get sngAttrTransactionId => "sng_attr_transaction_id";
	static String get sngAttrTutorialId => "sng_attr_tutorial_id";
	static String get sngAttrValid => "sng_attr_valid";
}
